@@ -49,11 +49,23 @@ class FetchResult(NamedTuple):
 
 
 class CursorConfig(NamedTuple):
-    """Cursor configurations."""
+    """Cursor configurations.
+
+
+    :param grpc_client: the cursor's gRPC client.
+    :type grpc_client: :class:`GRPCClient`
+    :param create_request_fn: the function to create gRPC requests given the items.
+    :type create_request_fn: Callable[[Iterable], "core_pb2.Request"]
+    :param parse_response_fn: the function to parse gRPC response
+    :type parse_response_fn: Optional[Callable[["core_pb2.Request"], Iterable]], optional
+    :param unary: send unary-unary gRPC requests. Defaults to `False`.
+    :type unary: bool, optional
+    """
 
     grpc_client: GRPCClient
-    create_request_fn: Callable[[Iterable], Iterator["core_pb2.Request"]]
-    parse_response_fn: Optional[Callable[["core_pb2.Response"], Iterable]] = None
+    create_request_fn: Callable[[Iterable], "core_pb2.Request"]
+    parse_response_fn: Optional[Callable[["core_pb2.Request"], Iterable]] = None
+    unary: Optional[bool] = False
 
 
 class Cursor:
@@ -61,7 +73,7 @@ class Cursor:
         self,
         config: CursorConfig,
         items: Iterable[np.ndarray],
-        batch_size: int = 100,
+        batch_size: Optional[int] = 100,
     ):
         """A cursor batch-processes requests sent to a service.
 
@@ -74,6 +86,7 @@ class Cursor:
         """
         self.batch_size = batch_size or 100
         self._item_iterator = iter(items)
+        self._unary = config.unary
         self._client = config.grpc_client
         self._create_reqeust_fn = config.create_request_fn
         self._parse_response_fn = config.parse_response_fn or self.identity
@@ -90,7 +103,7 @@ class Cursor:
         """Processes all of the items and returns the results."""
         return list(self._fetch_unbuffered())
 
-    def stream(self):
+    def stream(self) -> Iterator:
         """Processes all of the items, returns the results one batch at a time."""
         return self._fetch_unbuffered()
 
@@ -110,8 +123,8 @@ class Cursor:
 
         :param size: how many items to fetch.
         """
-        request_generator = self._generate_requests(size)
-        for response in self._client.stream_requests(request_generator):
+
+        def parse_response(response):
             if response.status.code == core_pb2.Status.StatusCode.Value("ERROR"):
                 exception = bool(response.status.details) and response.status.details[0].exception
                 error_msg = exception or response.status.description or "Unknown error when fetching results."
@@ -120,6 +133,17 @@ class Cursor:
             for elem in self._parse_response_fn(response):
                 yield elem
 
+        request_generator = self._generate_requests(size)
+        if self._unary:
+            for request in request_generator:
+                response_ = self._client.send_request(request)
+                for elem in parse_response(response_):
+                    yield elem
+        else:
+            for response_ in self._client.stream_requests(request_generator):
+                for elem in parse_response(response_):
+                    yield elem
+
     def _generate_requests(self, size: int = None) -> Iterator["core_pb2.Request"]:
         """Generates protobuf requests.
 
@@ -183,7 +207,13 @@ class Connection:
         self.grpc = GRPCClient(host=host, port=port, api_key=api_key, service_name=service_name, conn_timeout=timeout,
                                timeout=response_timeout, traceroute=traceroute)
 
-    def upsert(self, items: Iterable[Tuple[str, np.ndarray]], namespace: str = None, batch_size: int = None) -> Cursor:
+    def upsert(
+        self,
+        items: Iterable[Tuple[str, np.ndarray]],
+        namespace: str = None,
+        batch_size: int = None,
+        cursor_config: dict = None,
+    ) -> Cursor:
         """Inserts or updates items.
 
         Insert an item into the index, or update by item id if the item's id already exists.
@@ -194,6 +224,8 @@ class Connection:
         :type namespace: str, optional
         :param batch_size: overrides default batch size
         :type batch_size: int, optional
+        :param cursor_config: additional cursor configs. See :class:`CursorConfig`.
+        :type cursor_config: dict, optional
         :return: :class:`Cursor`
         """
 
@@ -207,12 +239,17 @@ class Connection:
         def _parse_index_response(response):
             return [IndexResult(id=_id) for _id in response.index.ids]
 
-        cursor_config = CursorConfig(
-            grpc_client=self.grpc, create_request_fn=_create_index_request, parse_response_fn=_parse_index_response
+        config = CursorConfig(
+            grpc_client=self.grpc,
+            create_request_fn=_create_index_request,
+            parse_response_fn=_parse_index_response,
+            **(cursor_config or {})
         )
-        return Cursor(config=cursor_config, items=items, batch_size=batch_size)
+        return Cursor(config=config, items=items, batch_size=batch_size)
 
-    def delete(self, ids: Iterable[str], namespace: str = None, batch_size: int = None) -> Cursor:
+    def delete(
+        self, ids: Iterable[str], namespace: str = None, batch_size: int = None, cursor_config: dict = None
+    ) -> Cursor:
         """Deletes items by their ids.
 
         :param ids: ids of items
@@ -221,6 +258,8 @@ class Connection:
         :type namespace: str, optional
         :param batch_size: overrides default batch size
         :type batch_size: int, optional
+        :param cursor_config: additional cursor configs. See :class:`CursorConfig`.
+        :type cursor_config: dict, optional
         :return: :class:`Cursor`
         """
 
@@ -232,12 +271,17 @@ class Connection:
         def _parse_delete_response(response):
             return [DeleteResult(id=_id) for _id in response.delete.ids]
 
-        cursor_config = CursorConfig(
-            grpc_client=self.grpc, create_request_fn=_create_delete_request, parse_response_fn=_parse_delete_response
+        config = CursorConfig(
+            grpc_client=self.grpc,
+            create_request_fn=_create_delete_request,
+            parse_response_fn=_parse_delete_response,
+            **(cursor_config or {})
         )
-        return Cursor(config=cursor_config, items=ids, batch_size=batch_size)
+        return Cursor(config=config, items=ids, batch_size=batch_size)
 
-    def fetch(self, ids: Iterable[str], namespace: str = None, batch_size: int = None) -> Cursor:
+    def fetch(
+        self, ids: Iterable[str], namespace: str = None, batch_size: int = None, cursor_config: dict = None
+    ) -> Cursor:
         """Fetches items by their ids.
 
         :param ids: ids of items
@@ -246,10 +290,12 @@ class Connection:
         :type namespace: str, optional
         :param batch_size: overrides default batch size
         :type batch_size: int, optional
+        :param cursor_config: additional cursor configs. See :class:`CursorConfig`.
+        :type cursor_config: dict, optional
         :return: :class:`Cursor`
         """
 
-        def _create_fetch_request(id_batch: Iterable[str]) -> Iterator["core_pb2.Request"]:
+        def _create_fetch_request(id_batch: Iterable[str]) -> "core_pb2.Request":
             """Generates a delete request."""
             path = "read"
             return self.grpc.get_fetch_request(ids=id_batch, namespace=namespace, path=path)
@@ -260,10 +306,13 @@ class Connection:
                 for _id, vector in zip(response.fetch.ids, response.fetch.vectors)
             ]
 
-        cursor_config = CursorConfig(
-            grpc_client=self.grpc, create_request_fn=_create_fetch_request, parse_response_fn=_parse_fetch_response
+        config = CursorConfig(
+            grpc_client=self.grpc,
+            create_request_fn=_create_fetch_request,
+            parse_response_fn=_parse_fetch_response,
+            **(cursor_config or {})
         )
-        return Cursor(config=cursor_config, items=ids, batch_size=batch_size)
+        return Cursor(config=config, items=ids, batch_size=batch_size)
 
     def query(
         self,
@@ -272,6 +321,7 @@ class Connection:
         top_k: int = 10,
         batch_size: int = None,
         include_data: bool = False,
+        cursor_config: dict = None,
     ) -> Cursor:
         """Sends queries to the index and returns the top results ordered by their scores.
 
@@ -286,6 +336,8 @@ class Connection:
         :type batch_size: int, optional
         :param include_data: whether to return data associated with the query results, defaults to False
         :type include_data: bool, optional
+        :param cursor_config: additional cursor configs. See :class:`CursorConfig`.
+        :type cursor_config: dict, optional
         :return: :class:`Cursor`
         """
 
@@ -307,15 +359,18 @@ class Connection:
                 for matches in response.query.matches
             ]
 
-        cursor_config = CursorConfig(
-            grpc_client=self.grpc, create_request_fn=_create_query_request, parse_response_fn=_parse_query_response
+        config = CursorConfig(
+            grpc_client=self.grpc,
+            create_request_fn=_create_query_request,
+            parse_response_fn=_parse_query_response,
+            **(cursor_config or {})
         )
-        return Cursor(config=cursor_config, items=queries, batch_size=batch_size)
+        return Cursor(config=config, items=queries, batch_size=batch_size)
 
-    def info(self, namespace: str = None) -> InfoResult:
+    def info(self, namespace: str = None) -> Optional[InfoResult]:
         """Returns information of the index."""
 
-        def _create_info_request(*args):
+        def _create_info_request(*args) -> "core_pb2.Request":
             path = "write"
             return self.grpc.get_info_request(namespace=namespace, path=path)
 
