@@ -5,7 +5,7 @@
 from pinecone.network.zmq import SocketType
 from pinecone.protos import core_pb2
 from pinecone.utils import module_name, get_memory_usage
-from pinecone.utils.constants import PERSISTENT_VOLUME_MOUNT, MEMORY_LIMIT_MB
+from pinecone.utils.constants import PERSISTENT_VOLUME_MOUNT, MEMORY_LIMIT_MB, NodeType
 
 import os.path, os
 import json
@@ -27,10 +27,11 @@ class Function:
         :return:
         """
         config = json.loads(args.config)
+        node_type = NodeType(args.node_type) if args.node_type else NodeType.STANDARD
         if 'image' in config:
             image = config.pop('image')
-            return cls(image, replicas=args.replicas, shards=args.shards, name=args.name, **config)
-        return cls(replicas=args.replicas, shards=args.shards, name=args.name, **config)
+            return cls(image, replicas=args.replicas, shards=args.shards, name=args.name, node_type=node_type, **config)
+        return cls(replicas=args.replicas, shards=args.shards, name=args.name, node_type=node_type, **config)
 
     def to_args(self):
         """
@@ -40,7 +41,8 @@ class Function:
         return ['--config', json.dumps(self.config, separators=(',', ':')),
                 '--replicas', str(self.replicas),
                 '--shards', str(self.shards),
-                '--name', str(self.name)]
+                '--name', str(self.name),
+                '--node_type', json.loads(json.dumps(self._node_type))]
 
     @classmethod
     def add_args(cls, parser: argparse.ArgumentParser):
@@ -48,6 +50,7 @@ class Function:
         parser.add_argument('--replicas', type=int, help='total number of replicas', default='1')
         parser.add_argument('--shards', type=int, help='total number of shards', default='1')
         parser.add_argument('--name', type=str, help='functions name')
+        parser.add_argument('--node_type', type=str, help='type of node to schedule function on')
 
     def __init__(self,
                  in_sock_type: SocketType = SocketType.PULL,
@@ -55,6 +58,7 @@ class Function:
                  replicas: int = 1,
                  shards: int = 1,
                  name: str = None,
+                 node_type: NodeType = NodeType.STANDARD,
                  **config):
         """
         :param config: kwargs must all be json-serializable settings for this functions
@@ -66,6 +70,7 @@ class Function:
         self._id = 0
         self._shards = shards
         self._name = name
+        self._node_type = node_type
 
     @property
     def image(self):
@@ -129,6 +134,13 @@ class Function:
         """
         return 500
 
+    @property
+    def cpu_request(self) -> int:
+        """
+        :return: Request CPU in 1/1000th of a core
+        """
+        return 2000 if self._node_type == NodeType.COMPUTE else 1000
+
     @property
     def volume_request(self) -> Optional[int]:
         """
