@@ -2,6 +2,10 @@
 # Copyright (c) 2020-2021 Pinecone Systems Inc. All right reserved.
 #
 
+from pinecone.utils.tracing import init_tracer, init_profiler
+init_tracer()
+init_profiler()
+
 from pinecone.network.zmq import Socket, SocketType, entrypoints
 from pinecone.network.zmq.spec import ServletSpec
 from pinecone.utils import load_hub_service, constants
