@@ -10,8 +10,9 @@ import pinecone
 from pinecone.specs import service as service_specs
 from pinecone.functions import Function
 from pinecone.functions.model import HubFunction
-from pinecone.functions.engine import namespaced
+from pinecone.functions.engine import namespaced, accelerated
 from pinecone.functions.ranker import aggregator
+from pinecone.utils.constants import NodeType
 
 __all__ = ["Graph", "IndexGraph"]
 
@@ -107,7 +108,8 @@ class IndexGraph(Graph):
     _default_engine = namespaced.NamespacedEngine
     _default_aggregator = aggregator.Aggregator
 
-    def __init__(self, engine_type: str = "approximated", metric: str = "cosine", shards: int = 1, replicas: int = 1):
+    def __init__(self, engine_type: str = "approximated", metric: str = "cosine", shards: int = 1, replicas: int = 1,
+                 node_type: NodeType = NodeType.STANDARD):
         """
 
         :param engine_type: type of engine, one of {"approximated", "exact"}, defaults to "approximated".
@@ -127,6 +129,8 @@ class IndexGraph(Graph):
             Use at least 2 replicas if you need high availability (99.99% uptime) for querying.
             For every 100 QPS your service needs to support, provision a replica.
         :type replicas: int, optional
+        :param node_type: type of node to schedule the workloads on e.g. "STANDARD", "COMPUTE"
+        :type node_type: NodeType, optional
         """
         super().__init__()
         self.preprocessors = {
@@ -136,7 +140,8 @@ class IndexGraph(Graph):
         self.postprocessors = []
 
         # The engine and the aggregator must be specified for an index service
-        self.engine = self._default_engine(engine_type, metric=metric, replicas=replicas, shards=shards, name="engine")
+        self.engine = self._default_engine(engine_type, metric=metric, replicas=replicas, shards=shards,
+                                           name="engine", node_type=node_type)
         self.aggregator = None if shards == 1 else self._default_aggregator(num_shards=shards, name="aggregator")
         self._update_graph()
 
