@@ -187,6 +187,10 @@ class ZMQService(Runnable):
     def memory_request(self) -> int:
         return self.function.memory_request
 
+    @property
+    def cpu_request(self) -> int:
+        return self.function.cpu_request
+
     @property
     def volume_request(self) -> Optional[int]:
         return self.function.volume_request
