@@ -3,6 +3,7 @@
 #
 
 import os
+import enum
 
 RECV_TIMEOUT = 0.5
 SEND_TIMEOUT = 0.5
@@ -28,3 +29,8 @@ MAX_MSGS_PENDING = 1000
 
 MEMORY_LIMIT_MB = int(os.environ.get("PINECONE_MEMORY_LIMIT_MB", default="0"))  # default is 0 - no limit
 MAX_ID_LENGTH = int(os.environ.get("PINECONE_MAX_ID_LENGTH", default="64"))
+
+
+class NodeType(str, enum.Enum):
+    STANDARD = 'STANDARD'
+    COMPUTE = 'COMPUTE'
